"use strict";
// (original from: https://gist.github.com/shimizu/fde15aa8cf734f1219f8)
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var d3 = require("d3");
var moment = require("moment");
var React = require("react");
var WorldClock = /** @class */ (function (_super) {
    __extends(WorldClock, _super);
    function WorldClock(props) {
        var _this = _super.call(this, props) || this;
        _this.create = _this.create.bind(_this);
        return _this;
    }
    WorldClock.prototype.componentDidMount = function () {
        this.create();
    };
    WorldClock.prototype.componentDidUpdate = function () {
        this.create();
    };
    WorldClock.prototype.create = function () {
        var _self = this;
        var node = this.node;
        var windowWidth = 960;
        var windowHeight = 500;
        node.style.width = windowWidth;
        node.style.height = windowHeight;
        var svg = d3.select(node);
        var projection90 = d3.geo.orthographic()
            .scale(windowWidth / 4)
            .rotate([0, 0, 0])
            .translate([windowWidth / 2, windowHeight / 2])
            .clipAngle(90);
        var projection180 = d3.geo.orthographic()
            .scale(windowWidth / 4)
            .rotate([0, 0, 0])
            .translate([windowWidth / 2, windowHeight / 2])
            .clipAngle(180);
        var frontPath = d3.geo.path().projection(projection90);
        var backPath = d3.geo.path().projection(projection180);
        d3.json("https://gist.githubusercontent.com/shimizu/97c156f7f9137586f784/raw/4be1053346fa88d448c2290c49689634c8102b0a/Landmasses.geojson", function (geojson) {
            /*************************************************************
             * 地球儀表示
             *************************************************************/
            var stage = svg.append("svg:g");
            //ステージを右23.4度傾ける
            // stage.attr("transform", "rotate(23.4, "+windowWidth/2+",  "+windowHeight/2+")");
            stage.attr("transform", "rotate(23.4, " + +windowWidth / 2 + ", " + windowHeight / 2 + ")");
            //地形(裏)
            var backMap = stage.append("svg:path")
                .attr({
                "d": function () { return backPath(geojson); },
                "fill-opacity": 1,
                "fill": "#EDE9F1",
                "stroke": "none",
            });
            //地形(表)
            var frontMap = stage.append("svg:path")
                .attr({
                "d": function () { return frontPath(geojson); },
                "fill-opacity": 1,
                "fill": "#FD81DB",
                "stroke": "none",
            });
            //地形を回転させる
            var update = function () {
                var i = 0;
                return function () {
                    i = i + 0.2;
                    projection90.rotate([i, 0, 0]);
                    projection180.rotate([i, 0, 0]);
                    frontPath = d3.geo.path().projection(projection90);
                    backPath = d3.geo.path().projection(projection180);
                    backMap.attr("d", backPath(geojson));
                    frontMap.attr("d", frontPath(geojson));
                };
            };
            setInterval(update(), 100);
            /*************************************************************
             * 時計表示
             *************************************************************/
            var marginLeft = windowWidth / 7;
            var marginTop = windowHeight / 3 + windowHeight / 12;
            var textY = 8;
            console.log("translate(" + [marginLeft, marginTop] + ")");
            var clockGroup = svg.append("g")
                .attr("transform", "translate(" + marginLeft + ", " + marginTop + ")");
            //テキスト背景描画
            var clockRect = clockGroup.append("rect")
                .attr({
                "width": "70%",
                "height": windowWidth / 10,
                "fill": "EDE9F1",
                "fill-opacity": 0.2
            });
            //テキスト描画
            var clockText = clockGroup.append("text")
                .attr({
                "x": "10",
                "y": windowWidth / 11,
                "font-size": 110,
                "font-weight": "bold",
                "font-family": "arial",
                "line-height": 1.5,
                "letter-spacing": 5,
                "word-spacing": 5
            });
            //テキスト更新
            setInterval(function () {
                clockText.text(moment().format('HH:mm:ss:SS'));
            }, 1);
        });
    };
    WorldClock.prototype.render = function () {
        var _this = this;
        return React.createElement("svg", { ref: function (node) { return _this.node = node; } });
    };
    return WorldClock;
}(React.Component));
exports.default = WorldClock;
//# sourceMappingURL=index.js.map